@@ -16,14 +16,11 @@ use tower_cookies::{CookieManagerLayer, Cookies};
 use tokio::sync::{mpsc, oneshot};
 
 use rustdb::{
-    genquery::{GenQuery, Part},
-    init::INITSQL,
-    pstore::SharedPagedData,
-    stg::SimpleFileStorage,
-    Database,
+    c_value, check_types, AccessPagedData, Block, CExp, CExpPtr, CompileFunc, DataKind, Database,
+    EvalEnv, Expr, GenQuery, Part, SharedPagedData, SimpleFileStorage, Value, DB, INITSQL,
 };
 
-use std::{collections::HashMap, sync::Arc, thread};
+use std::{collections::HashMap, rc::Rc, sync::Arc, thread};
 
 /// Query to be sent to server thread, implements IntoResponse.
 struct ServerQuery {
@@ -53,7 +50,15 @@ struct SharedState {
     spd: Arc<SharedPagedData>,
 }
 
-/// Main function ( execution starts here ).
+fn get_db(apd: AccessPagedData, sql: &str) -> DB {
+    let db = Database::new(apd, sql);
+    let list = [("ARGON", DataKind::Binary, CompileFunc::Value(c_argon))];
+    for (name, typ, cf) in list {
+        db.register(name, typ, cf);
+    }
+    db
+}
+
 #[tokio::main]
 async fn main() {
     // console_subscriber::init();
@@ -65,11 +70,11 @@ async fn main() {
     let (tx, mut rx) = mpsc::channel::<ServerMessage>(1);
 
     let state = Arc::new(SharedState { tx, spd });
-    let wstg = state.spd.open_write();
+    let wapd = state.spd.open_write();
 
     // This is the server thread (synchronous).
     thread::spawn(move || {
-        let db = Database::new(wstg, INITSQL);
+        let db = get_db(wapd, INITSQL);
         loop {
             let mut sm = rx.blocking_recv().unwrap();
             db.run_timed("EXEC web.Main()", &mut *sm.sq.x);
@@ -100,17 +105,6 @@ fn map_cookies(cookies: Cookies) -> HashMap<String, String> {
         result.insert(name.to_string(), value.to_string());
     }
     result
-
-    /*
-    cookies
-        .list()
-        .iter()
-        .map(|cookie| {
-            let (name, value) = cookie.name_value();
-            (name.to_string(), value.to_string())
-        })
-        .collect()
-    */
 }
 
 /// Get Vec of Parts from MultiPart.
@@ -163,8 +157,8 @@ async fn h_get(
 
     let blocking_task = tokio::task::spawn_blocking(move || {
         // GET requests should be read-only.
-        let d = state.spd.open_read();
-        let db = Database::new(d, "");
+        let apd = state.spd.open_read();
+        let db = get_db(apd, "");
         db.run_timed("EXEC web.Main()", &mut *sq.x);
         sq
     });
@@ -221,3 +215,28 @@ impl IntoResponse for ServerQuery {
         res
     }
 }
+
+/////////////////////////////
+
+use argon2rs::argon2i_simple;
+
+/// Compile call to ARGON.
+fn c_argon(b: &Block, args: &mut [Expr]) -> CExpPtr<Value> {
+    check_types(b, args, &[DataKind::String, DataKind::String]);
+    let password = c_value(b, &mut args[0]);
+    let salt = c_value(b, &mut args[1]);
+    Box::new(Argon { password, salt })
+}
+struct Argon {
+    password: CExpPtr<Value>,
+    salt: CExpPtr<Value>,
+}
+impl CExp<Value> for Argon {
+    fn eval(&self, ee: &mut EvalEnv, d: &[u8]) -> Value {
+        let pw = self.password.eval(ee, d).str();
+        let salt = self.salt.eval(ee, d).str();
+
+        let result = argon2i_simple(&pw, &salt).to_vec();
+        Value::Binary(Rc::new(result))
+    }
+}
