@@ -40,6 +40,8 @@
 //!    }
 //!```
 //!
+//![See here](https://github.com/georgebarwood/RustDB/blob/main/examples/axumtest.rs) for more advanced example (Axum webserver with ARGON hash function).
+//!
 //!General Design of Database
 //!
 //!SortedFile stores fixed size Records in a tree of Pages.
@@ -57,20 +59,35 @@
 //!
 //!Each page is implemented as a binary tree ( so there is a tree of trees ).
 
+pub use crate::{
+    genquery::{GenQuery, Part},
+    init::INITSQL,
+    pstore::{AccessPagedData, SharedPagedData},
+    stg::SimpleFileStorage,
+};
+
+#[cfg(feature = "builtin")]
+pub use crate::{
+    builtin::check_types,
+    compile::{c_bool, c_float, c_int, c_value},
+    exec::EvalEnv,
+    expr::{Block, DataKind, Expr},
+    run::{CExp, CExpPtr, CompileFunc},
+    value::Value,
+};
+
 use crate::{
     bytes::ByteStorage,
     compact::CompactFile,
-    exec::EvalEnv,
     expr::*,
     page::{Page, PagePtr},
     parse::Parser,
-    pstore::AccessPagedData,
     run::*,
     sortedfile::{Asc, Id, Record, SortedFile},
     stg::Storage,
     table::{ColInfo, IndexInfo, Row, SaveOp, Table, TablePtr},
     util::newmap,
-    value::{get_bytes, Value},
+    value::get_bytes,
 };
 use parking_lot::{Mutex, RwLock};
 use std::{
@@ -108,9 +125,11 @@ pub mod stg;
 pub mod pstore;
 
 // Conditional modules.
-#[cfg(target_os = "windows")]
-/// Optimised implementatation of ```Storage``` (windows only).
-pub mod stgwin;
+
+// #[cfg(target_os = "windows")]
+// Optimised implementatation of ```Storage``` (windows only).
+// This didn't work out - actually ran slower!
+// pub mod stgwin;
 
 #[cfg(feature = "max")]
 /// Compilation of builtin functions.
